@@ -19,7 +19,7 @@ class BreakpointItem;
 
 class BreakpointTable : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     BreakpointTable(TQWidget* parent, const char* name);
     ~BreakpointTable();
