@@ -47,16 +47,16 @@ KDebugger::KDebugger(TQWidget* parent,
 {
     m_envVars.setAutoDelete(true);
 
-    connect(&m_localVariables, SIGNAL(expanded(TQListViewItem*)),
-	    SLOT(slotExpanding(TQListViewItem*)));
-    connect(&m_watchVariables, SIGNAL(expanded(TQListViewItem*)),
-	    SLOT(slotExpanding(TQListViewItem*)));
-    connect(&m_localVariables, SIGNAL(editValueCommitted(VarTree*, const TQString&)),
-	    SLOT(slotValueEdited(VarTree*, const TQString&)));
-    connect(&m_watchVariables, SIGNAL(editValueCommitted(VarTree*, const TQString&)),
-	    SLOT(slotValueEdited(VarTree*, const TQString&)));
+    connect(&m_localVariables, TQ_SIGNAL(expanded(TQListViewItem*)),
+	    TQ_SLOT(slotExpanding(TQListViewItem*)));
+    connect(&m_watchVariables, TQ_SIGNAL(expanded(TQListViewItem*)),
+	    TQ_SLOT(slotExpanding(TQListViewItem*)));
+    connect(&m_localVariables, TQ_SIGNAL(editValueCommitted(VarTree*, const TQString&)),
+	    TQ_SLOT(slotValueEdited(VarTree*, const TQString&)));
+    connect(&m_watchVariables, TQ_SIGNAL(editValueCommitted(VarTree*, const TQString&)),
+	    TQ_SLOT(slotValueEdited(VarTree*, const TQString&)));
 
-    connect(&m_btWindow, SIGNAL(highlighted(int)), SLOT(gotoFrame(int)));
+    connect(&m_btWindow, TQ_SIGNAL(highlighted(int)), TQ_SLOT(gotoFrame(int)));
 
     emit updateUI();
 }
@@ -111,19 +111,19 @@ bool KDebugger::debugProgram(const TQString& name,
     }
 
     // wire up the driver
-    connect(driver, SIGNAL(activateFileLine(const TQString&,int,const DbgAddr&)),
-	    this, SIGNAL(activateFileLine(const TQString&,int,const DbgAddr&)));
-    connect(driver, SIGNAL(processExited(TDEProcess*)), SLOT(gdbExited(TDEProcess*)));
-    connect(driver, SIGNAL(commandReceived(CmdQueueItem*,const char*)),
-	    SLOT(parse(CmdQueueItem*,const char*)));
-    connect(driver, SIGNAL(wroteStdin(TDEProcess*)), SIGNAL(updateUI()));
-    connect(driver, SIGNAL(inferiorRunning()), SLOT(slotInferiorRunning()));
-    connect(driver, SIGNAL(enterIdleState()), SLOT(backgroundUpdate()));
-    connect(driver, SIGNAL(enterIdleState()), SIGNAL(updateUI()));
-    connect(&m_localVariables, SIGNAL(removingItem(VarTree*)),
-	    driver, SLOT(dequeueCmdByVar(VarTree*)));
-    connect(&m_watchVariables, SIGNAL(removingItem(VarTree*)),
-	    driver, SLOT(dequeueCmdByVar(VarTree*)));
+    connect(driver, TQ_SIGNAL(activateFileLine(const TQString&,int,const DbgAddr&)),
+	    this, TQ_SIGNAL(activateFileLine(const TQString&,int,const DbgAddr&)));
+    connect(driver, TQ_SIGNAL(processExited(TDEProcess*)), TQ_SLOT(gdbExited(TDEProcess*)));
+    connect(driver, TQ_SIGNAL(commandReceived(CmdQueueItem*,const char*)),
+	    TQ_SLOT(parse(CmdQueueItem*,const char*)));
+    connect(driver, TQ_SIGNAL(wroteStdin(TDEProcess*)), TQ_SIGNAL(updateUI()));
+    connect(driver, TQ_SIGNAL(inferiorRunning()), TQ_SLOT(slotInferiorRunning()));
+    connect(driver, TQ_SIGNAL(enterIdleState()), TQ_SLOT(backgroundUpdate()));
+    connect(driver, TQ_SIGNAL(enterIdleState()), TQ_SIGNAL(updateUI()));
+    connect(&m_localVariables, TQ_SIGNAL(removingItem(VarTree*)),
+	    driver, TQ_SLOT(dequeueCmdByVar(VarTree*)));
+    connect(&m_watchVariables, TQ_SIGNAL(removingItem(VarTree*)),
+	    driver, TQ_SLOT(dequeueCmdByVar(VarTree*)));
 
     // create the program settings object
     openProgramConfig(name);
@@ -2175,8 +2175,7 @@ void KDebugger::slotValueEdited(VarTree* expr, const TQString& text)
 	return;			       /* no text entered: ignore request */
 
     ExprWnd* wnd = static_cast<ExprWnd*>(expr->listView());
-    TRACE(TQString().sprintf("Changing %s to ",
-			    wnd->name()) + text);
+    TRACE(TQString("Changing %1 to ").arg(wnd->name()) + text);
 
     // determine the lvalue to edit
     TQString lvalue = expr->computeExpr();
