@@ -39,7 +39,7 @@ class TDEProcess;
 
 class KDebugger : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     KDebugger(TQWidget* parent,		/* will be used as the parent for dialogs */
 	      ExprWnd* localVars,
