@@ -7,9 +7,9 @@
 #include "exprwnd.h"
 #include "exprwnd.moc"
 #include "typetable.h"
-#include <ntqstringlist.h>
-#include <ntqpainter.h>
-#include <ntqscrollbar.h>
+#include <tqstringlist.h>
+#include <tqpainter.h>
+#include <tqscrollbar.h>
 #include <tdeapplication.h>
 #include <kiconloader.h>		/* icons */
 #include <tdelocale.h>			/* i18n */
@@ -761,12 +761,12 @@ ValueEdit::ValueEdit(ExprWnd* parent) :
     setFrame(false);
     hide();
     lower();	// lower the window below scrollbars
-    connect(parent, SIGNAL(selectionChanged()), SLOT(slotSelectionChanged()));
-    connect(parent, SIGNAL(currentChanged(TQListViewItem*)), SLOT(slotSelectionChanged()));
-    connect(parent, SIGNAL(expanded(TQListViewItem*)), SLOT(slotSelectionChanged()));
-    connect(parent, SIGNAL(collapsed(TQListViewItem*)), SLOT(slotSelectionChanged()));
-    connect(this, SIGNAL(done(VarTree*, const TQString&)),
-	    parent, SIGNAL(editValueCommitted(VarTree*, const TQString&)));
+    connect(parent, TQ_SIGNAL(selectionChanged()), TQ_SLOT(slotSelectionChanged()));
+    connect(parent, TQ_SIGNAL(currentChanged(TQListViewItem*)), TQ_SLOT(slotSelectionChanged()));
+    connect(parent, TQ_SIGNAL(expanded(TQListViewItem*)), TQ_SLOT(slotSelectionChanged()));
+    connect(parent, TQ_SIGNAL(collapsed(TQListViewItem*)), TQ_SLOT(slotSelectionChanged()));
+    connect(this, TQ_SIGNAL(done(VarTree*, const TQString&)),
+	    parent, TQ_SIGNAL(editValueCommitted(VarTree*, const TQString&)));
 }
 
 ValueEdit::~ValueEdit()
