@@ -12,7 +12,7 @@
 
 class GdbDriver : public DebuggerDriver
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     GdbDriver();
     ~GdbDriver();
