@@ -7,10 +7,10 @@
 #ifndef PREFMISC_H
 #define PREFMISC_H
 
-#include <ntqlayout.h>
-#include <ntqcheckbox.h>
-#include <ntqlabel.h>
-#include <ntqlineedit.h>
+#include <tqlayout.h>
+#include <tqcheckbox.h>
+#include <tqlabel.h>
+#include <tqlineedit.h>
 
 class PrefMisc : public TQWidget
 {
