@@ -25,7 +25,7 @@ class TDEProcess;
 
 class ProcAttachPS : public ProcAttachBase
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     ProcAttachPS(TQWidget* parent);
     ~ProcAttachPS();
