@@ -27,11 +27,11 @@ WinStack::WinStack(TQWidget* parent, const char* name) :
 	m_tabWidth(0)
 {
     connect(&m_findDlg.m_buttonForward,
-	    SIGNAL(clicked()), SLOT(slotFindForward()));
+	    TQ_SIGNAL(clicked()), TQ_SLOT(slotFindForward()));
     connect(&m_findDlg.m_buttonBackward,
-	    SIGNAL(clicked()), SLOT(slotFindBackward()));
+	    TQ_SIGNAL(clicked()), TQ_SLOT(slotFindBackward()));
 
-    connect(this, SIGNAL(setTabWidth(int)), this, SLOT(slotSetTabWidth(int)));
+    connect(this, TQ_SIGNAL(setTabWidth(int)), this, TQ_SLOT(slotSetTabWidth(int)));
 }
 
 WinStack::~WinStack()
@@ -115,19 +115,19 @@ bool WinStack::activatePath(TQString pathName, int lineNo, const DbgAddr& addres
 	addTab(fw, TQFileInfo(pathName).fileName());
 	setTabToolTip(fw, pathName);
 
-	connect(fw, SIGNAL(clickedLeft(const TQString&,int,const DbgAddr&,bool)),
-		SIGNAL(toggleBreak(const TQString&,int,const DbgAddr&,bool)));
-	connect(fw, SIGNAL(clickedMid(const TQString&,int,const DbgAddr&)),
-		SIGNAL(enadisBreak(const TQString&,int,const DbgAddr&)));
+	connect(fw, TQ_SIGNAL(clickedLeft(const TQString&,int,const DbgAddr&,bool)),
+		TQ_SIGNAL(toggleBreak(const TQString&,int,const DbgAddr&,bool)));
+	connect(fw, TQ_SIGNAL(clickedMid(const TQString&,int,const DbgAddr&)),
+		TQ_SIGNAL(enadisBreak(const TQString&,int,const DbgAddr&)));
 
 	// disassemble code
-	connect(fw, SIGNAL(disassemble(const TQString&, int)),
-		SIGNAL(disassemble(const TQString&, int)));
-	connect(fw, SIGNAL(expanded(int)), SLOT(slotExpandCollapse(int)));
-	connect(fw, SIGNAL(collapsed(int)), SLOT(slotExpandCollapse(int)));
+	connect(fw, TQ_SIGNAL(disassemble(const TQString&, int)),
+		TQ_SIGNAL(disassemble(const TQString&, int)));
+	connect(fw, TQ_SIGNAL(expanded(int)), TQ_SLOT(slotExpandCollapse(int)));
+	connect(fw, TQ_SIGNAL(collapsed(int)), TQ_SLOT(slotExpandCollapse(int)));
 
 	// tab width
-	connect(this, SIGNAL(setTabWidth(int)), fw, SLOT(setTabWidth(int)));
+	connect(this, TQ_SIGNAL(setTabWidth(int)), fw, TQ_SLOT(setTabWidth(int)));
 	fw->setTabWidth(m_tabWidth);
 	fw->setFocusPolicy(TQWidget::WheelFocus);
 
@@ -412,7 +412,7 @@ FindDialog::FindDialog() :
     m_buttonBackward.setMinimumSize(maxSize);
     m_buttonClose.setMinimumSize(maxSize);
 
-    connect(&m_buttonClose, SIGNAL(clicked()), SLOT(reject()));
+    connect(&m_buttonClose, TQ_SIGNAL(clicked()), TQ_SLOT(reject()));
 
     m_layout.addWidget(&m_searchText);
     m_layout.addWidget(&m_caseCheck);
